@@ -10,7 +10,8 @@ use Raisin::Request;
 use Raisin::Response;
 use Raisin::Routes;
 
-our $VERSION = '0.23.0';
+our $VERSION = '0.1';
+our $CODENAME = 'Cabernet Sauvignon';
 
 sub new {
     my ($class, %args) = @_;
@@ -229,7 +230,7 @@ __END__
 
 =head1 NAME
 
-Raisin - REST-like API micro-framework for Perl.
+Raisin - A REST-like API micro-framework for Perl.
 
 =head1 SYNOPSIS
 
@@ -251,8 +252,8 @@ Raisin - REST-like API micro-framework for Perl.
     namespace '/user' => sub {
         get params => [
             #required/optional => [name, type, default, regex]
-            optional => ['start', 'Raisin::Types::Integer', 0],
-            optional => ['count', 'Raisin::Types::Integer', 10],
+            optional => ['start', $Raisin::Types::Integer, 0],
+            optional => ['count', $Raisin::Types::Integer, 10],
         ],
         sub {
             my $params = shift;
@@ -270,9 +271,9 @@ Raisin - REST-like API micro-framework for Perl.
         };
 
         post params => [
-            required => ['name', 'Raisin::Types::String'],
-            required => ['password', 'Raisin::Types::String'],
-            optional => ['email', 'Raisin::Types::String', undef, qr/.+\@.+/],
+            required => ['name', $Raisin::Types::String],
+            required => ['password', $Raisin::Types::String],
+            optional => ['email', $Raisin::Types::String, undef, qr/.+\@.+/],
         ],
         sub {
             my $params = shift;
@@ -283,7 +284,7 @@ Raisin - REST-like API micro-framework for Perl.
             { success => 1 }
         };
 
-        route_param 'id' => 'Raisin::Types::Integer',
+        route_param 'id' => $Raisin::Types::Integer,
         sub {
             get sub {
                 my $params = shift;
@@ -302,88 +303,37 @@ It was inspired by L<Grape|https://github.com/intridea/grape>.
 
 =head1 KEYWORDS
 
-=head2 namespace
-
-Adds a route to application.
+=head3 namespace
 
     namespace user => sub { ... };
 
-=head2 route_param
+=head3 route_param
 
-Define a route parameter as a namespace C<route_param>.
+    route_param id => $Raisin::Types::Integer, sub { ... };
 
-    route_param id => 'Raisin::Types::Integer', sub { ... };
-
-=head2 delete, get, post, put
+=head3 delete, get, post, put
 
 These are shortcuts to C<route> restricted to the corresponding HTTP method.
 
-Each method could consists of max three parameters:
-
-=over
-
-=item *
-
-params
-
-=item *
-
-subroutine
-
-=item *
-
-path
-
-=back
-
-Where only C<subroutine> is required.
-
     get sub { 'GET' };
 
-    delete 'all' => sub { 'OK' };
-
     get params => [
-        required => ['id', 'Raisin::Types::Integer'],
-        optional => ['key', 'Raisin::Types::String'],
+        required => ['id', $Raisin::Types::Integer],
+        optional => ['key', $Raisin::Types::String],
     ],
     sub { 'GET' };
 
-    put params => [
-        required => ['id', 'Raisin::Types::Integer'],
-        optional => ['name', 'Raisin::Types::String'],
-    ],
-    'all' => sub {
-        'GET'
-    };
-
-=head2 req
+=head3 req
 
 An alias for C<$self-E<gt>req>, this provides quick access to the
 L<Raisin::Request> object for the current route.
 
-Use C<req> to get access to the request headers, params, etc.
-
-    use DDP;
-    p req->headers;
-    p req->params;
-
-    say req->header('X-Header');
-
-See also L<Plack::Request>.
-
-=head2 res
+=head3 res
 
 An alias for C<$self-E<gt>res>, this provides quick access to the
 L<Raisin::Response> object for the current route.
 
-Use C<res> to set up response parameters.
-
-    res->status(403);
-    res->headers(['X-Application' => 'Raisin Application']);
-
-See also L<Plack::Response>.
-
-=head2 params
+=head3 params
 
 An alias for C<$self-E<gt>params> that gets the GET and POST parameters.
 When used with no arguments, it will return an array with the names of all http
@@ -391,41 +341,33 @@ parameters. Otherwise, it will return the value of the requested http parameter.
 
 Returns L<Hash::MultiValue> object.
 
-    say req->params->{name};
-
-=head2 session
+=head3 session
 
 An alias for C<$self-E<gt>session> that returns (optional) psgix.session hash.
 When it exists, you can retrieve and store per-session data from and to this hash.
 
-    # store param
-    session->{hello} = 'World!';
-
-    # read param
-    say session->{name};
-
-=head2 api_version
+=head3 api_version
 
 Set an API version header.
 
     api_version 1.23;
 
-=head2 api_format
+=head3 api_format
 
-Loads a plugin from C<Raisin::Plugin::Format> namespace.
+Load a C<Raisin::Plugin::Format> plugin.
 
 Already exists L<Raisin::Plugin::Format::JSON> and L<Raisin::Plugin::Format::YAML>.
 
     api_format 'JSON';
 
-=head2 plugin
+=head3 plugin
 
 Loads a Raisin module. The module options may be specified after the module name.
 Compatible with L<Kelp> modules.
 
     plugin 'Logger' => outputs => [['Screen', min_level => 'debug']];
 
-=head2 middleware
+=head3 middleware
 
 Loads middleware to your application.
 
@@ -433,7 +375,7 @@ Loads middleware to your application.
     middleware '+Plack::Middleware::ContentLength';
     middleware 'Runtime'; # will be loaded Plack::Middleware::Runtime
 
-=head2 mount
+=head3 mount
 
 Mount multiple API implementations inside another one.  These don't have to be
 different versions, but may be components of the same API.
@@ -451,11 +393,11 @@ In C<RaisinApp.pm>:
 
     1;
 
-=head2 run, new
+=head3 run, new
 
 Creates and returns a PSGI ready subroutine, and makes the app ready for C<Plack>.
 
-=head1 PARAMETERS
+=head2 Parameters
 
 Request parameters are available through the params hash object. This includes
 GET, POST and PUT parameters, along with any named parameters you specify in
@@ -486,7 +428,7 @@ route string parameters will have precedence.
 
 Query string and body parameters will be merged (see L<Plack::Request/parameters>)
 
-=head2 Validation and coercion
+=head3 Validation and coercion
 
 You can define validations and coercion options for your parameters using a params block.
 
@@ -494,8 +436,8 @@ Parameters can be C<required> and C<optional>. C<optional> parameters can have a
 default value.
 
     get params => [
-        required => ['name', 'Raisin::Types::String'],
-        optional => ['number', 'Raisin::Types::Integer', 10],
+        required => ['name', $Raisin::Types::String],
+        optional => ['number', $Raisin::Types::Integer, 10],
     ],
     sub {
         my $params = shift;
@@ -527,7 +469,7 @@ regex
 
 Optional parameters can have a default value.
 
-=head2 Types
+=head3 Types
 
 Here is built-in types
 
@@ -535,10 +477,6 @@ Here is built-in types
 
 =item *
 
-L<Raisin::Types::Float>
-
-=item *
-
 L<Raisin::Types::Integer>
 
 =item *
@@ -554,7 +492,7 @@ L<Raisin::Types::Scalar>
 You can create your own types as well. See examples in L<Raisin::Types>.
 Also see L<Raisin::Types::Base>.
 
-=head1 HOOKS
+=head2 Hooks
 
 This blocks can be executed before or after every API call, using
 C<before>, C<after>, C<before_validation> and C<after_validation>.
@@ -597,8 +535,8 @@ Steps 3 and 4 only happen if validation succeeds.
 
 =head1 API FORMATS
 
-By default, Raisin supports C<YAML>, C<JSON>, and C<TEXT> content-types.
-The default format is C<TEXT>.
+By default, Raisin supports C<YAML>, C<JSON>, and C<TXT> content-types.
+The default format is C<TXT>.
 
 Serialization takes place automatically. For example, you do not have to call
 C<encode_json> in each C<JSON> API implementation.
@@ -610,17 +548,23 @@ Your API can declare which types to support by using C<api_format>.
 Custom formatters for existing and additional types can be defined with a
 L<Raisin::Plugin::Format>.
 
-=head2 JSON
+Built-in formats are the following:
 
-Call C<JSON::encode_json> and C<JSON::decode_json>.
+=over
 
-=head2 YAML
+=item *
 
-Call C<YAML::Dump> and C<JSON::Load>.
+C<JSON>: call JSON::encode_json.
 
-=head2 TEXT
+=item *
 
-Call C<Data::Dumper-E<gt>Dump> if output data is not a string.
+C<YAML>: call YAML::Dump.
+
+=item *
+
+C<TXT>: call Data::Dumper->Dump if not SCALAR.
+
+=back
 
 The order for choosing the format is the following.
 
@@ -628,24 +572,35 @@ The order for choosing the format is the following.
 
 =item *
 
-Use the C<api_format> if specified.
+Use the C<api_format> set by the C<api_format> option, if specified.
 
 =item *
 
-Fallback to C<TEXT>.
+Default to C<TXT>.
 
 =back
 
+=head1 HEADERS
+
+Use C<res> to set up response headers. See L<Plack::Response>.
+
+    res->headers(['X-Application' => 'Raisin Application']);
+
+Use C<req> to read request headers. See L<Plack::Request>.
+
+    req->header('X-Application');
+    req->headers;
+
 =head1 AUTHENTICATION
 
 TODO
-L<Raisin::Plugin::Auth>
-L<Raisin::Plugin::Auth::Basic>
-L<Raisin::Plugin::Auth::Token>
+Built-in plugin L<Raisin::Plugin::Authentication>
+L<Raisin::Plugin::Authentication::Basic>
+L<Raisin::Plugin::Authentication::Digest>
 
 =head1 LOGGING
 
-Raisin has a built-in logger based on C<Log::Dispatch>. You can enable it by
+Raisin has a buil-in logger based on Log::Dispatch. You can enable it by
 
     plugin 'Logger' => outputs => [['Screen', min_level => 'debug']];
 
@@ -663,14 +618,14 @@ L<Swagger|https://github.com/wordnik/swagger-core> compatible API documentations
 
     plugin 'APIDocs';
 
-Documentation available on C<http://E<lt>urlE<gt>/api-docs> URL.
+Documentation available on C<http://E<lt>urlE<gt>/api-docs> url.
 
 For more see L<Raisin::Plugin::APIDocs>.
 
 =head1 MIDDLEWARE
 
 You can easily add any L<Plack> middleware to your application using
-C<middleware> keyword. See L<Raisin/middleware>.
+C<middleware> keyword.
 
 =head1 PLUGINS
 
@@ -678,7 +633,7 @@ Raisin can be extended using custom I<modules>. Each new module must be a subcla
 of the C<Raisin::Plugin> namespace. Modules' job is to initialize and register new
 methods into the web application class.
 
-For more see L<Raisin/plugin> and L<Raisin::Plugin>.
+For more see L<Raisin::Plugin>.
 
 =head1 TESTING
 
@@ -702,10 +657,7 @@ See L<Plack::Test>, L<Test::More> and etc.
 
 =head1 DEPLOYING
 
-Deploying a Raisin application is done the same way any other Plack
-application is deployed:
-
-    > plackup -E deployment -s Starman app.psgi
+See L<Plack::Builder>, L<Plack::App::URLMap>.
 
 =head2 Kelp
 
@@ -754,24 +706,18 @@ application is deployed:
         mount '/api/rest' => RaisinApp->new;
     };
 
-Also see L<Plack::Builder>, L<Plack::App::URLMap>.
+=head1 GitHub
 
-=head1 EXAMPLES
-
-See examples.
-
-=head1 GITHUB
-
-L<https://github.com/khrt/Raisin|https://github.com/khrt/Raisin>
+https://github.com/khrt/Raisin
 
 =head1 AUTHOR
 
-Artur Khabibullin - rtkh E<lt>atE<gt> cpan.org
+Artur Khabibullin - khrt <at> ya.ru
 
 =head1 ACKNOWLEDGEMENTS
 
-This module was inspired both by Grape and L<Kelp>,
-which was inspired by L<Dancer>, which in its turn was inspired by Sinatra.
+This module was inspired by L<Kelp>, which was inspired by L<Dancer>,
+which in its turn was inspired by Sinatra.
 
 =head1 LICENSE
 
