@@ -2,6 +2,7 @@ package Raisin::API;
 
 use strict;
 use warnings;
+use feature ':5.12';
 
 use base 'Exporter';
 
@@ -33,6 +34,7 @@ sub import {
 
     strict->import;
     warnings->import;
+    feature->import(':5.12');
 
     my $caller = caller;
     $app ||= Raisin->new(caller => $caller);
@@ -82,13 +84,14 @@ sub namespace {
     (join '/', @NS) || '/';
 }
 
+
 sub route_param {
     my ($param, $type, $block) = @_;
     namespace(":$param", $block, named => [required => [$param, $type]]);
 }
 
 #
-# Actions
+# Action DSL
 #
 sub delete  { $app->add_route('DELETE',  namespace(), %SETTINGS, @_) }
 sub get     { $app->add_route('GET',     namespace(), %SETTINGS, @_) }
@@ -107,28 +110,15 @@ sub params { $app->params(@_) }
 sub session { $app->session(@_) }
 
 #
-# System
+#
 #
 sub plugin { $app->load_plugin(@_) }
-
 sub api_format { $app->api_format(@_) }
 sub api_version { $app->api_version(@_) }
 
-#
-# Render
-#
-sub error { $app->res->render_error(@_) }
+#sub error {
+#    # NOTE render error 500?
+#    $app->res->render_error(@_);
+#}
 
 1;
-
-__END__
-
-=head1 NAME
-
-Raisin::API - Provides Raisin DSL.
-
-=head1 DESCRIPTION
-
-See L<Raisin>.
-
-=cut
