@@ -13,20 +13,20 @@ sub build {
     my ($self, @args) = @_;
     my $logger = $self->{logger} = Log::Dispatch->new(@args);
 
-#    # Register a few levels
-#    my @levels_to_register = qw/debug info error/;
-#
-#    # Build the registration hash
-#    my %LEVELS = map {
-#        my $level = $_;
-#        $level => sub {
-#            shift if ref($_[0]);
-#            $self->message($level, @_);
-#        };
-#    } @levels_to_register;
-#
-#    # Register the log levels
-#    $self->register(%LEVELS);
+    # Register a few levels
+    my @levels_to_register = qw/debug info error/;
+
+    # Build the registration hash
+    my %LEVELS = map {
+        my $level = $_;
+        $level => sub {
+            shift if ref($_[0]);
+            $self->message($level, @_);
+        };
+    } @levels_to_register;
+
+    # Register the log levels
+    $self->register(%LEVELS);
 
     # Also register the message method as 'logger'
     $self->register(logger => sub {
@@ -53,27 +53,4 @@ sub message {
 
 1;
 
-__END__
-
-=head1 NAME
-
-Raisin::Plugin::Logger - Logger plugin for Raisin.
-
-=head1 SYNOPSIS
-
-    plugin 'Logger';
-    logger(info => 'Hello!');
-
-=head1 DESCRIPTION
-
-Borrowed from L<Kelp::Module::Logger>.
-
-Provides C<logger> method which is an alias for L<Log::Dispatch> C<log> method.
-
-    $self->{logger}->log(
-        level   => $level,
-        message => sprintf("%s - %s - %s\n",
-            $date, $level, ref($_) ? Dumper($_) : $_)
-    );
-
-=cut
+### L<Kelp::Plugin::Logger>
