@@ -37,19 +37,12 @@ sub add {
         return;
     }
 
-    # Named route params
-    if (scalar @args == 1 || scalar @args == 3) {
-        $path = $path . '/' . shift(@args);
-    }
-
     my @params;
     if (@args && (my %args = @args)) {
         foreach my $key (qw(params named)) {
             for (my $i = 0; $i < scalar @{ $args{$key} || [] }; $i += 2) {
-                push @params, Raisin::Param->new(
-                    named => $key eq 'named' ? 1 : 0,
-                    param => [$args{$key}[$i], $args{$key}[$i + 1]]
-                );
+                my ($type, $options) = ($args{$key}[$i], $args{$key}[$i + 1]);
+                push @params, Raisin::Param->new($key, $type, $options);
             }
         }
     }
@@ -94,8 +87,6 @@ sub find {
     my @found
     #   = sort { $b->bridge <=> $a->bridge || $a->pattern cmp $b->pattern }
         = grep { $_->match($method, $path) } @$routes;
-#use DDP;
-#p @found;
 
     $self->cache->{$cache_key} = \@found;
     \@found;
@@ -107,7 +98,7 @@ __END__
 
 =head1 NAME
 
-Raisin::Routes - Routing class for Raisin.
+Raisin::Routes - Routing
 
 =head1 SYNOPSIS
 
@@ -155,7 +146,7 @@ Optional
 
     /user/?id
 
-=head1 METHODS
+=head1 SUBROUTINES
 
 =head2 add
 
@@ -165,6 +156,10 @@ Adds a new route
 
 Looking for a route
 
+=over
+
+=cut
+
 =head1 ACKNOWLEDGEMENTS
 
 This module was inspired by L<Kelp::Routes>.
