@@ -3,16 +3,6 @@ package Raisin::Routes::Endpoint;
 use strict;
 use warnings;
 
-use Raisin::Attributes;
-
-has 'check' => {};
-has 'code';
-has 'method';
-has 'params';
-has 'path';
-has 'regex';
-has 'tokens_re';
-
 sub new {
     my ($class, %args) = @_;
     my $self = bless {}, $class;
@@ -20,19 +10,26 @@ sub new {
     @$self{keys %args} = values %args;
 
     # Populate params index
+    $self->{check} = {};
     for (@{ $self->params }) {
         if ($_->named && (my $re = $_->regex)) {
-            if (my $re = $_->regex) {
-                $re =~ s/[\$^]//g;
-                $self->{check}{ $_->name } = $re;
-            }
+            $re =~ s/[\$^]//g;
+            $self->{check}{ $_->name } = $re;
         }
     }
 
-    $self->regex($self->_build_regex);
+    $self->{regex} = $self->_build_regex;
     $self;
 }
 
+sub check { shift->{check} }
+sub code { shift->{code} }
+sub method { shift->{method} }
+sub params { shift->{params} }
+sub path { shift->{path} }
+sub regex { shift->{regex} }
+sub tokens_re { shift->{tokens_re} }
+
 sub _build_regex {
     my ($self, %args) = @_;
     return $self->path if ref($self->path) eq 'Regexp';
@@ -73,13 +70,6 @@ sub match {
     return if not (my @matched = $path =~ $self->regex);
 
     my %named = map { $_ => $+{$_} } keys %+;
-
-    foreach my $p (@{ $self->params }) {
-        next unless $p->named;
-        my $copy = $named{$p->name};
-        return unless $p->validate(\$copy, 'shh!');
-    }
-
     $self->named(\%named);
 
     1;
@@ -97,10 +87,10 @@ __END__
 
 =head1 NAME
 
-Raisin::Routes::Endpoint - Endpoint class for Raisin::Routes.
+Raisin::Routes::Endpoint
 
 =head1 ACKNOWLEDGEMENTS
 
-This module borrowed from L<Kelp::Routes::Pattern>.
+This module heavily borrowed from L<Kelp::Routes::Pattern>.
 
 =cut
